@@ -193,6 +193,8 @@ OC.L10N.register(
     "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
     "Warnings" : "Avisos",
+    "Prevent warning dialogs from open or reenable them." : "Evitar que se abran los diálogos de advertencia o volver a habilitarlos.",
+    "Show a warning dialog when changing a file extension." : "Mostrar un diálogo de advertencia cuando se cambia la extensión de un archivo.",
     "Keyboard shortcuts" : "Atajos de teclado",
     "Speed up your Files experience with these quick shortcuts." : "Acelera tu experiencia con Archivos con esos atajos de teclado.",
     "Open the actions menu for a file" : "Abrir el menú de acciones para un archivo",
@@ -229,11 +231,15 @@ OC.L10N.register(
     "Creating file" : "Creando el archivo",
     "Save as {displayName}" : "Guardar como {displayName}",
     "Save as …" : "Guardar como ...",
+    "Converting files …" : "Convirtiendo archivos …",
     "Failed to convert files: {message}" : "Fallo al convertir archivos: {message}",
     "All files failed to be converted" : "Todos los archivos han fallado al convertirse",
     "One file could not be converted: {message}" : "Un archivo no ha podido ser convertido: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Un archivo no pudo ser convertido","%n archivos no pudieron ser convertidos","%n archivos no pudieron ser convertidos"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Un archivo convertido exitosamente","%n archivos convertidos exitosamente","%n archivos convertidos exitosamente"],
     "Files successfully converted" : "Archivos convertidos correctamente",
     "Failed to convert files" : "Fallo al convertir archivos",
+    "Converting file …" : "Convirtiendo archivo …",
     "File successfully converted" : "Archivo convertido correctamente",
     "Failed to convert file: {message}" : "Fallo al convertir el archivo: {message}",
     "Failed to convert file" : "Fallo al convertir el archivo",
@@ -276,6 +282,7 @@ OC.L10N.register(
     "Open file locally" : "Abrir archivo localmente",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "El archivo se abrirá ahora en tu dispositivo. Si esto no ocurre, por favor verifica que has instalado la aplicación de escritorio",
     "Retry and close" : "Reintentar y cerrar",
+    "Open online" : "Abrir en línea",
     "Failed to redirect to client" : "Fallo al redirigir al cliente",
     "Open locally" : "Abrir localmente",
     "Rename" : "Renombrar",
@@ -324,6 +331,7 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archivo y {folderCount} carpeta","1 archivo y {folderCount} carpetas","1 archivo y {folderCount} carpetas"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archivo y 1 carpeta","{fileCount} archivos y 1 carpeta","{fileCount} archivos y 1 carpeta"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} archivos y {folderCount} carpetas",
+    "_(%n hidden)_::_ (%n hidden)_" : ["(%n oculto)"," (%n ocultos)"," (%n ocultos)"],
     "Filename must not be empty." : "El nombre de archivo no debe estar vacío.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" no está permitido en el nombre de archivo.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" es un nombre reservado y no se permite para los nombres de archivo.",
@@ -429,6 +437,7 @@ OC.L10N.register(
     "Upload file" : "Subir archivo",
     "Not favorited" : "Quitado como favorito",
     "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
+    "You don't have permission to upload or create files here." : "No tiene permisos para subir o crear archivos aquí.",
     "Storage informations" : "Informaciones de almacenamiento",
     "Choose file" : "Elegir archivo",
     "Go to the previous folder" : "Ir a la carpeta anterior",
