@@ -235,6 +235,8 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "無法轉換檔案：{message}",
     "All files failed to be converted" : "所有檔案轉換失敗",
     "One file could not be converted: {message}" : "有一個檔案無法轉換：{message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["%n 個檔案無法轉換"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["%n 個檔案成功轉換"],
     "Files successfully converted" : "成功轉換檔案",
     "Failed to convert files" : "無法轉換檔案",
     "Converting file …" : "正在轉換檔案 …",
@@ -329,6 +331,7 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
+    "_(%n hidden)_::_ (%n hidden)_" : ["（%n 隱藏）"],
     "Filename must not be empty." : "檔案名稱不能為空。",
     "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "「{segment}」是保留名稱，不允許用在檔案名稱。",
