@@ -40,26 +40,26 @@ OC.L10N.register(
     "<strong>System tags</strong> for a file have been modified" : "As <strong>etiquetas de sistema</strong> para um arquivo foram modificadas",
     "Files" : "Arquivos",
     "Tags" : "Etiquetas",
-    "All tagged %s …" : "Todos os %s marcados …",
-    "tagged %s" : "marcado %s",
+    "All tagged %s …" : "Todos com etiqueta %s …",
+    "tagged %s" : "etiquetado como %s",
     "Collaborative tags" : "Etiquetas colaborativas",
-    "Collaborative tagging functionality which shares tags among people." : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas.",
-    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas. Ótimo para equipes. \n\t(Se você for um provedor com instalação multilocatária, é aconselhável desativar este aplicativo, pois as etiquetas são compartilhadas.)",
+    "Collaborative tagging functionality which shares tags among people." : "Funcionalidade de etiquetas colaborativas que compartilha etiquetas entre pessoas.",
+    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de etiquetas colaborativas que compartilha etiquetas entre pessoas. Ótimo para equipes. \n\t(Se você for um provedor com instalação multi-tenancy, é recomendável desativar este aplicativo, pois as etiquetas são compartilhadas.)",
     "Public" : "Público",
     "Restricted" : "Restrito",
     "Invisible" : "Invisível",
     "Created tag" : "Etiqueta criada",
     "Failed to create tag" : "Falha ao criar etiqueta",
     "Updated tag" : "Etiqueta atualizada",
-    "Failed to update tag" : "Falha ao atualizar a etiqueta",
+    "Failed to update tag" : "Falha ao atualizar etiqueta",
     "Deleted tag" : "Etiqueta excluída",
     "Failed to delete tag" : "Falha ao excluir etiqueta",
     "Create or edit tags" : "Criar ou editar etiquetas",
-    "Search for a tag to edit" : "Procure uma etiqueta para editar",
-    "Collaborative tags …" : "Etiquetas colaborativas…",
+    "Search for a tag to edit" : "Pesquisar uma etiqueta para editar",
+    "Collaborative tags …" : "Etiquetas colaborativas …",
     "No tags to select" : "Nenhuma etiqueta para selecionar",
     "Tag name" : "Nome da etiqueta",
-    "Tag level" : "Nível de etiqueta",
+    "Tag level" : "Nível da etiqueta",
     "Create" : "Criar",
     "Update" : "Atualizar",
     "Delete" : "Excluir",
@@ -70,26 +70,26 @@ OC.L10N.register(
     "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} será removido de 1 arquivo.","{tag} será removido de {count} arquivos.","{tag} será removido de {count} arquivos."],
     "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} e {lastTag} serão definidos em 1 arquivo.","{tags} e {lastTag} serão definidos em {count} arquivos.","{tags} e {lastTag} serão definidos em {count} arquivos."],
     "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} e {lastTag} serão removidos de 1 arquivo.","{tags} e {lastTag} serão removidos de {count} arquivos.","{tags} e {lastTag} serão removidos de {count} arquivos."],
-    "{displayName} (hidden)" : "{displayName} (escondida)",
-    "{displayName} (restricted)" : "{displayName} (restrita)",
+    "{displayName} (hidden)" : "{displayName} (escondido)",
+    "{displayName} (restricted)" : "{displayName} (restrito)",
     "Only admins can create new tags" : "Somente os administradores podem criar novas etiquetas",
     "Failed to apply tags changes" : "Falha ao aplicar alterações de etiquetas",
     "File tags modification canceled" : "Modificação de etiquetas de arquivo cancelada",
     "Manage tags" : "Gerenciar etiquetas",
-    "Applying tags changes…" : "Aplicando mudanças de etiquetas…",
+    "Applying tags changes…" : "Aplicando alterações de etiquetas…",
     "Search or create tag" : "Pesquisar ou criar etiqueta",
     "Search tag" : "Pesquisar etiqueta",
     "Change tag color" : "Alterar cor da etiqueta",
-    "Create new tag" : "Crie uma etiqueta nova",
+    "Create new tag" : "Criar etiqueta nova",
     "Select or create tags to apply to all selected files" : "Selecione ou crie etiquetas para aplicar a todos os arquivos selecionados",
     "Select tags to apply to all selected files" : "Selecione etiquetas para aplicar a todos os arquivos selecionados",
     "Cancel" : "Cancelar",
     "Apply changes" : "Aplicar alterações",
-    "Failed to load tags" : "Erro ao carregar rótulos",
+    "Failed to load tags" : "Erro ao carregar etiquetas",
     "Failed to load selected tags" : "Falha ao carregar as etiquetas selecionadas",
     "Failed to select tag" : "Falha ao selecionar etiqueta",
     "System admin disabled tag creation. You can only use existing ones." : "O administrador do sistema desativou a criação de etiquetas. Você só pode usar as que já existem.",
-    "Loading collaborative tags …" : "Carregando etiquetas,s colaborativas…",
+    "Loading collaborative tags …" : "Carregando etiquetas colaborativas …",
     "Search or create collaborative tags" : "Pesquise ou crie etiquetas colaborativas",
     "No tags to select, type to create a new tag" : "Nenhuma etiqueta para selecionar, digite para criar uma nova etiqueta",
     "Unable to update setting" : "Não foi possível atualizar a configuração",
@@ -97,16 +97,16 @@ OC.L10N.register(
     "System tag creation is now allowed for everybody" : "A criação de etiquetas do sistema agora está liberada para todos",
     "System tag management" : "Gerenciamento de etiquetas do sistema",
     "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Se ativado, somente os administradores poderão criar e editar etiquetas. As contas ainda podem atribuí-las e removê-las dos arquivos.",
-    "Restrict tag creation and editing to administrators" : "Restringir a criação e a edição de atiquetas aos administradores",
+    "Restrict tag creation and editing to administrators" : "Restringir a criação e a edição de etiquetas aos administradores",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Etiquetas colaborativas estão disponíveis para todos os usuários. As etiquetas restritas são visíveis para os usuários, mas não podem ser atribuídas por eles. Etiquetas invisíveis são para uso interno, já que os usuários não podem vê-las ou atribuí-las.",
     "Assigned collaborative tags" : "Etiquetas colaborativas atribuídas",
-    "Open in Files" : "Abrir em arquivos",
+    "Open in Files" : "Abrir em Arquivos",
     "List of tags and their associated files and folders." : "Lista de etiquetas e seus arquivos e pastas associados.",
     "No tags found" : "Nenhuma etiqueta encontrada",
-    "Tags you have created will show up here." : "Asetiquetas que você criou aparecerão aqui.",
+    "Tags you have created will show up here." : "As etiquetas que você criou aparecerão aqui.",
     "Failed to load tag" : "Falha ao carregar etiqueta",
     "Failed to load last used tags" : "Falha ao carregar as últimas etiquetas usadas",
-    "Missing \"Content-Location\" header" : "Cabeçalho \"Conteúdo-Localização\" ausente",
+    "Missing \"Content-Location\" header" : "Cabeçalho \"Content-Location\" ausente",
     "A tag with the same name already exists" : "Uma etiqueta com o mesmo nome já existe",
     "Failed to load tags for file" : "Falha ao carregar etiquetas para arquivo",
     "Failed to set tag for file" : "Falha ao definir etiqueta para arquivo",
